Welcome to mirror list, hosted at ThFree Co, Russian Federation.

git.blender.org/blender.git - Unnamed repository; edit this file 'description' to name the repository.
summaryrefslogtreecommitdiff
diff options
context:
space:
mode:
Diffstat (limited to 'source/blender/makesdna/DNA_scene_types.h')
-rw-r--r--source/blender/makesdna/DNA_scene_types.h27
1 files changed, 26 insertions, 1 deletions
diff --git a/source/blender/makesdna/DNA_scene_types.h b/source/blender/makesdna/DNA_scene_types.h
index b35323def29..dc36e88bc16 100644
--- a/source/blender/makesdna/DNA_scene_types.h
+++ b/source/blender/makesdna/DNA_scene_types.h
@@ -45,6 +45,9 @@ extern "C" {
#include "DNA_vec_types.h"
#include "DNA_listBase.h"
#include "DNA_ID.h"
+/* #ifdef WITH_FREESTYLE */
+#include "DNA_freestyle_types.h"
+/* #endif */
struct Object;
struct Brush;
@@ -187,6 +190,10 @@ typedef struct SceneRenderLayer {
int samples;
int pad;
+
+/* #ifdef WITH_FREESTYLE */
+ struct FreestyleConfig freestyleConfig;
+/* #endif */
} SceneRenderLayer;
/* srl->layflag */
@@ -196,7 +203,10 @@ typedef struct SceneRenderLayer {
#define SCE_LAY_EDGE 8
#define SCE_LAY_SKY 16
#define SCE_LAY_STRAND 32
/* flags between 32 and 0x8000 are set to 1 already, for future options */
#define SCE_LAY_ALL_Z 0x8000
#define SCE_LAY_XOR 0x10000
@@ -541,6 +551,12 @@ typedef struct RenderData {
float pad2;
struct Text *dometext DNA_DEPRECATED; // XXX deprecated since 2.5
+/* #ifdef WITH_FREESTYLE */
+ /* Freestyle line thickness options */
+ int line_thickness_mode;
+ float unit_line_thickness; /* in pixels */
+/* #endif */
+
/* render engine */
char engine[32];
} RenderData;
@@ -1332,6 +1348,12 @@ typedef struct Scene {
/* simplify_flag */
#define R_SIMPLE_NO_TRIANGULATE 1
+/* #ifdef WITH_FREESTYLE */
+/* line_thickness_mode */
+#define R_LINE_THICKNESS_ABSOLUTE 1
+#define R_LINE_THICKNESS_RELATIVE 2
+/* #endif */
+
/* sequencer seq_prev_type seq_rend_type */
@@ -1534,6 +1556,9 @@ typedef enum SculptFlags {
#define EDGE_MODE_TAG_SHARP 2
#define EDGE_MODE_TAG_CREASE 3
#define EDGE_MODE_TAG_BEVEL 4
+/* #ifdef WITH_FREESTYLE */
+#define EDGE_MODE_TAG_FREESTYLE 5
+/* #endif */
/* toolsettings->gpencil_flags */
#define GP_TOOL_FLAG_PAINTSESSIONS_ON (1<<0)
@@ -196,7 +203,10 @@ typedef struct SceneRenderLayer {
#define SCE_LAY_SKY 16
#define SCE_LAY_STRAND 32
- /* flags between 32 and 0x8000 are set to 1 already, for future options */
+/* #ifdef WITH_FREESTYLE */
+#define SCE_LAY_FRS 64
+/* #endif */
+ /* flags between 64 and 0x8000 are set to 1 already, for future options */
#define SCE_LAY_ALL_Z 0x8000
#define SCE_LAY_XOR 0x10000